@@ -2,7 +2,8 @@ from __future__ import unicode_literals
 
 from django.conf.urls import patterns
 
-from .utils import show_user, promo
+from .views import promo
+from .views import show_user
 
 
 urlpatterns = patterns('', (r'^user/$', show_user), (r'^promo/$', promo))
